/***************************************************************************/
/*                                                                         */
/*                           Repalette handler                             */
/*                                                                         */
/***************************************************************************/

#ifndef __REPALETTE_H
#define __REPALETTE_H

#include "kisshdr.h"

/***************************************************************************/
/*
 * In (nearly) all cases, these routines return an integer status value.
 * status=0 => success, other values from the list below.
 */

#define REPALETTE_K_OUTOFMEM    1
#define REPALETTE_K_MISMPALETTE 2
#define REPALETTE_K_SAVECEL     3
#define REPALETTE_K_NOTCHERRY   4
#define REPALETTE_K_READCEL     5
#define REPALETTE_K_READKCF     6
#define REPALETTE_K_READKCF2    7

/**************************************************************************/
/*
 * Create a pixel colour translation table from one palette to another.
 */

extern byte *repalette_CreatePixelTransTable(paletteword *palette,
                                             int          numold,
                                             paletteword *newpalette,
                                             int          numnew);

/**************************************************************************/
/*
 * Dispose of the malloc'ed memory used to store cel pixels.
 */

extern void repalette_DisposeCel(CEL_DESCRIPTOR *cel);

/**************************************************************************/
/*
 * Perform the actual pixel translation from one cel to another.
 */

extern int repalette_ProcessCel( CEL_DESCRIPTOR *cel,
                                 byte           *pixtrans,
                                 int             newnumcols,
                                 CEL_DESCRIPTOR *newcel);

/**************************************************************************/
/*
 * Save a cel.
 */

extern int repalette_SaveCelFile(char           *filename,
                                 CEL_DESCRIPTOR *cel);

/**************************************************************************/
/*
 * Read a palette file into memory.
 * If reqdcols is zero, any legal palette is acceptable; if reqdcols
 * is greater than zero, the function also validates the size of palette.
 */

extern int repalette_ReadPaletteFile(char         *filename,
                                     int          grp,
                                     int          *numcols,
                                     paletteword **palette,
                                     int          reqdcols);

/**************************************************************************/
/*
 * Read a cel into memory.
 */

extern int repalette_ReadCelFile(char           *filename,
                                 CEL_DESCRIPTOR *cel);

/**************************************************************************/
/*
 * Highest-level possible interface to repalette functions.
 */

extern int repalette_ProcessFile(char  *celfile,
                                 char  *oldpalfile,
                                 char  *newpalfile,
                                 char  *outfile);

#endif
